package c07repetition.lecture.pyramids;

import processing.core.PApplet;

/**
 * Pyramids draws a set of Sierpinski triangles of a given order.
 *
 * @author kvlinden
 * @version Fall, 2009
 * @version ported to Java, Spring, 2012
 */
public class PyramidsPanel extends PApplet {

	private final int N = 7;
	private int n, ox1, oy1, ox2, oy2, ox3, oy3;

	public void setup() {
	  size(800, 800);
	  background(255);
	  smooth();
	  n = 1;
	  frameRate(5);
	}

	public void draw() {
	  background(0);
	  ox1 = width/2;
	  oy1 = 10;
	  ox2 = 10;
	  oy2 = height - 10;
	  ox3 = width - 10;
	  oy3 = height - 10;
	  drawTriangles(n, ox1, oy1, ox2, oy2, ox3, oy3);
	  if (n < N) {
	    n++;
	  } 
	  else {
	    //save("sierpinski.png");
	    stop();
	  }
	}

	private void drawTriangles(int n, int x1, int y1, int x2, int y2, int x3, int y3) {
	  if (n >= 0) {
	    if (n == 0) {
	      fill(0);
	    } else {
	      float ax = (x1 + x2 + x3)/3, ay = (y1 + y2 + y3)/3;
	      fill(mapColorValue(ox1, oy1, ax, ay), mapColorValue(ox2, oy2, ax, ay), mapColorValue(ox3, oy3, ax, ay));
	    }
	    triangle(x1, y1, x2, y2, x3, y3);
	    drawTriangles(n-1, x1, y1, (x1+x2)/2, (y1+y2)/2, (x1+x3)/2, (y1+y3)/2);
	    drawTriangles(n-1, x2, y2, (x2+x1)/2, (y2+y1)/2, (x2+x3)/2, (y2+y3)/2);
	    drawTriangles(n-1, x3, y3, (x3+x2)/2, (y3+y2)/2, (x3+x1)/2, (y3+y1)/2);
	  }
	}

	float mapColorValue(float x1, float y1, float x2, float y2) {
	  return 255 - (map(dist(x1, y1, x2, y2), 0, height/2, 0, 125));
	}

	public void keyPressed() {
	  // This won't execute after the program has stopped (see above).
	  save("sierpinski.png");
	}

}
