package c07repetition.lecture.treeGUI;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 * TreeController presents a recursive tree drawing, allowing the user to change the recursive
 * branching angle and the random length/angle noise factor.
 * 
 * @author kvlinden
 * @version Fall, 2009
 */
@SuppressWarnings("serial")
public class TreeController extends JFrame implements ChangeListener {

	private static final int MAX_BRANCH_ANGLE_DEGREES = 360, DEFAULT_BRANCH_ANGLE_DEGREES = 90;
	private TreePanel treePanel;
	private JSlider angleSlider, noiseSlider;

	public TreeController() {
		super("Tree");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		treePanel = new TreePanel(DEFAULT_BRANCH_ANGLE_DEGREES);
		treePanel.init();
		add(treePanel, BorderLayout.NORTH);

		JPanel angleController = new JPanel();
		angleController.setLayout(new FlowLayout());
		angleController.add(new JLabel("Recursive Branching Angle: "));
		angleSlider = new JSlider(JSlider.HORIZONTAL, 0, MAX_BRANCH_ANGLE_DEGREES, DEFAULT_BRANCH_ANGLE_DEGREES);
		angleSlider.setMajorTickSpacing(60);
		angleSlider.setPaintTicks(true);
		angleSlider.setPaintLabels(true);
		angleSlider.addChangeListener(this);
		angleController.add(angleSlider);
		add(angleController, BorderLayout.CENTER);

		JPanel noiseController = new JPanel();
		noiseController.setLayout(new FlowLayout());
		noiseController.add(new JLabel("Noise Factor: "));
		noiseSlider = new JSlider(JSlider.HORIZONTAL, 0, 25, 0);
		noiseSlider.addChangeListener(this);
		noiseController.add(noiseSlider);
		add(noiseController, BorderLayout.SOUTH);

	}

	@Override
	public void stateChanged(ChangeEvent e) {
		JSlider slider = (JSlider) e.getSource();
		int value = slider.getValue();
		if (slider == angleSlider) {
			treePanel.setBranchAngle(value);
		} else if (slider == noiseSlider) {
			treePanel.setNoiseFactor(value/50.0);
		}
	}

	public static void main(String[] args) {
		TreeController application = new TreeController();
		application.pack();
		application.setVisible(true);
	}

}
