/* areaChooserApproximator animates the approximation of the definite integral of 
 * a choosen function from 0 to 1. Press the mouse button to animate the approximation
 * rectangles; release it to clear the rectangles.
 *
 * @author kvlinden
 * @version 14july2009
 */

final int SQRT = 0, SQ = 1, LINE = 2;
int functionMode = SQ;
boolean animating;

int menuWidth = 100, menuHeight = menuWidth/2, xAxisWidth = 300, width = menuWidth + xAxisWidth, height = xAxisWidth;
int xAxis = height-25, yAxis = 25;
float xMax = 1.0, scale = (xAxisWidth - yAxis) / xMax, xMin = -yAxis / scale;
int n;
float area;

void setup() {
  size(width, height);
  textFont(loadFont("Calibri-20.vlw"));
  n = 1;
  animating = false;
  //  noLoop();
  frameRate(4);
}

void draw() {
  background(255);
  drawMenu();
  drawAxes(xAxis, yAxis);
  plotFunction();
  if (animating) {
    area = drawApproximationRectangles(n++);
  }
  println(area);
  if (n > 100) noLoop();
}

float drawApproximationRectangles(int n) {
  float result = 0;
  float x, y, rectangleWidth = xMax / n;
  for (int i = 0; i < n; i++) {
    x = i * rectangleWidth;
    y = computeY(x);
    plotRectangle(x, y, rectangleWidth, y);
    result += rectangleWidth * y;
  }
  return result;
}

void plotRectangle(float x, float y, float width, float height) {
  fill(168, 128, 234);
  rect(translateX(x), translateY(y), 
  translateDistance(width), translateDistance(height));
}

void plotFunction() {
  stroke(0);
  for (float x = 0; x <= xMax; x += 0.0001) {
    point(translateX(x), translateY(computeY(x)));
  }
}

float translateX(float value) {
  return value * scale + menuWidth + yAxis;
}

float translateY(float value) {
  return value * -1 * scale + xAxis;
}

float translateDistance(float value) {
  return value * scale;
}

float computeY(float x) {
  switch(functionMode) {
  case SQRT:
    return sqrt(x);
  case SQ:
    return sq(x);
  case LINE:
    return 0.5 * x + 0.3;
  default:  
    return 0.0;
  }
}

void drawMenu() {
  fill(255);
  rect(0, 0, menuWidth, menuHeight);
  rect(0, menuHeight, menuWidth, menuHeight);
  rect(0, menuHeight * 2, menuWidth, menuHeight);
  fill(0);
  text("sqrt(x)", 10, 20);
  text("sq(x)", 10, menuHeight + 20);
  text("0.5x * 0.3", 10, menuHeight*2 + 20);
}

void drawAxes(int x, int y) {
  stroke(200);
  line(menuWidth, xAxis, width, xAxis); // x axis
  line(menuWidth + yAxis, 0, menuWidth + yAxis, height); // y axis
}

void mouseClicked() {
  if (mouseX < menuWidth) {
    if ((mouseY >= 0) && (mouseY < menuHeight)) {
      functionMode = SQRT;
    } 
    else if ((mouseY >= menuHeight) && (mouseY < menuHeight * 2)) {
      functionMode = SQ;
    }
    else if ((mouseY >= menuHeight * 2) && (mouseY < menuHeight * 3)) {
      functionMode = LINE;
    }
    n = 1;
  }
}

void mousePressed() {
  animating = true;
  n = 1;
}
void mouseReleased() {
  animating = false;
}

void keyPressed() {
  save("../../../../text/c05control/areaApproximation.tif");
}





