/* functionChooserPlotter plots the selected function from 0 to 1.
 *
 * @author kvlinden
 * @version 14july2009
 */

final int SQRT = 0, SQ = 1, LINE = 2;
int functionMode = SQRT;

int menuWidth = 100, menuHeight = menuWidth/2, xAxisWidth = 300, width = menuWidth + xAxisWidth, height = xAxisWidth;
int xAxis = height-25, yAxis = 25;
float xMax = 1.0, scale = (xAxisWidth - yAxis) / xMax, xMin = -yAxis / scale;

void setup() {
  size(width, height);
  background(255);
  textFont(loadFont("Calibri-20.vlw"));
}

void draw() {
  background(255);
  drawMenu();
  drawAxes(xAxis, yAxis);
  plotFunction();
}

// This method plots the function for each value on the x axis.
void plotFunction() {
  stroke(0);
  for (float x = 0; x <= xMax; x += 0.0001) {
    point(translateX(x), translateY(computeY(x)));
  }
}

// This method converts the raw x coordinate to be plotted into the appropriate 
// canvas value.
float translateX(float value) {
  return value * scale + menuWidth + yAxis;
}

// This method inverts the y value for plotting on the canvas.
float translateY(float value) {
  return value * -1 * scale + xAxis;
}

// This method computes the appropriate function value for x depending upon which 
// function the user has chosen.
float computeY(float x) {
  switch(functionMode) {
  case SQRT:
    return sqrt(x);
  case SQ:
    return sq(x);
  case LINE:
    return 0.5 * x + 0.3;
  default:  
    return 0.0;
  }
}

// This method draws the function chooser menu on the left of the canvas.
void drawMenu() {
  fill(255);
  rect(0, 0, menuWidth, menuHeight);
  rect(0, menuHeight, menuWidth, menuHeight);
  rect(0, menuHeight * 2, menuWidth, menuHeight);
  fill(0);
  text("sqrt(x)", 10, 20);
  text("sq(x)", 10, menuHeight + 20);
  text("0.5x * 0.3", 10, menuHeight*2 + 20);
}

// This method draws the axes in a location that leaves room for the chooser buttons.
void drawAxes(int x, int y) {
  stroke(200);
  line(menuWidth, xAxis, width, xAxis); // x axis
  line(menuWidth + yAxis, 0, menuWidth + yAxis, height); // y axis
}

// This method determines which function the user has selected.
void mouseClicked() {
  if (mouseX < menuWidth) {
    if ((mouseY >= 0) && (mouseY < menuHeight)) {
      functionMode = SQRT;
    } 
    else if ((mouseY >= menuHeight) && (mouseY < menuHeight * 2)) {
      functionMode = SQ;
    }
    else if ((mouseY >= menuHeight * 2) && (mouseY < menuHeight * 3)) {
      functionMode = LINE;
    }
  }
}

void keyPressed() {
  save("functionPlot.tif");
}












