/* polygonSpring allows the user to drag the polygon around and to 
 * restart the animation, and the system moves the polygon back to 
 * the center when the user isn't dragging it.
 *
 * @author kvlinden
 * @version 16july2009
 */

int width = 300, height = width, polygonX = width / 2, polygonY = height / 2, polygonDiameter = 100, polygonRadius = polygonDiameter / 2;
int numSides;

void setup() {
  size(width, height);
  smooth();
  numSides = 4;
}

void draw() {
  background(255);
  //ellipse(polygonX, polygonY, polygonDiameter, polygonDiameter);
  strokeWeight(5);
  point(polygonX, polygonY);
  float area = drawPolygon(numSides+=2);
  println("Area - actual = " + PI * polygonRadius * polygonRadius + " approximate = " + area);
  if (!mousePressed) {
    polygonX -= (polygonX - (width / 2)) * 0.1;
    polygonY -= (polygonY - (height / 2)) * 0.1;
  }
}

float drawPolygon(int sides) {
  if (sides < 2) {
    println("invalid number of sides: " + sides + "\nsimplePolygon exiting");
    exit();
  }
  float angle = 360.0 / sides, theta1, theta2;
  strokeWeight(1);
  for (int i = 0; i < sides; i = i+1) {
    if (i % 2 == 0) {
      fill(random(255), random(255), random(255));
    } 
    else {
      fill(0);
    }
    theta1 = radians(angle * i);
    theta2 = radians(angle * (i + 1));
    triangle(polygonX, polygonY, 
    polygonX + cos(theta1) * polygonRadius, 
    polygonY + sin(theta1) * polygonRadius, 
    polygonX + cos(theta2) * polygonRadius, 
    polygonY + sin(theta2) * polygonRadius);
  }
  // Compute area using regular polygon area formula.
  return (sides * polygonRadius * polygonRadius * sin(2 * PI / sides)) / 2.0;
}

void mouseClicked() {
  numSides = 0;
}
void mouseDragged() {
  if ((abs(mouseX - polygonX) <= polygonRadius) && (abs(mouseY - polygonY) <= polygonRadius)) {
    polygonX += mouseX - pmouseX;
    polygonY += mouseY - pmouseY;
  }
}

void keyPressed() {
  save("../../../../text/c05control/polygonSpring.tif");
}








