/** 
 * Koch draws a Koch snowflake using recursion.
 * (reference: Curran Kelleher, "Recursive Structures and Processes", MIT, 2007)
 *
 * @author kvlinden
 * @version Fall, 2009
 */

final int DEPTH = 10, SIZE = 500;
int depth;

void setup() {
  size(SIZE, SIZE);
  background(200);
  smooth();
  depth = 0;
  frameRate(3);
}

void draw() {
  //background(200);
  float ax = SIZE * 1/4, ay = SIZE/2 + tan(radians(30))*SIZE/4;
  float bx = SIZE * 3/4, by = SIZE/2 + tan(radians(30))*SIZE/4;
  float cx = SIZE/2, cy = SIZE/2 - SIZE/4 / cos(radians(30));
  drawCurve(ax, ay, SIZE/2, 0, depth);
  drawCurve(bx, by, SIZE/2, -PI * 2/3, depth);
  drawCurve(cx, cy, SIZE/2, PI * 2/3, depth);
  fill(255);
  noStroke();
  triangle(ax, ay, cx, cy, bx, by);
  if (depth < DEPTH) {
    depth++;
  }
}

void drawCurve(float x1, float y1, float rootLength, float rootAngle, int depth) {
  float unitX = cos(rootAngle), unitY = sin(rootAngle);
  float dx = unitX * rootLength, dy = unitY * rootLength;
  if (depth > 0) {
    float ax = x1 + dx * 1 / 3, ay = y1 + dy * 1 / 3;
    float bx = x1 + dx * 2 / 3, by = y1 + dy * 2 / 3;
    float d = rootLength / 3, h = sqrt(3) / 2 * d;
    float cx = x1 + dx / 2 - unitY * h, cy = y1 + dy / 2 + unitX * h;
    fill(255);
    noStroke();
    triangle(ax, ay, cx, cy, bx, by);
    drawCurve(x1, y1, d, rootAngle, depth - 1);
    drawCurve(ax, ay, d, rootAngle + PI / 3, depth - 1);
    drawCurve(cx, cy, d, rootAngle - PI / 3, depth - 1);
    drawCurve(bx, by, d, rootAngle, depth - 1);
  } 
  else {
    stroke(0);
    line(x1, y1, x1 + dx, y1 + dy);
  }
}






