/**
 * CountryNameConverter translates the country names in the GapMinder life-expectancy 
 * data (see http://www.gapminder.org/gapminder-world/documentation/) into ISO standard 
 * names (see http://www.iso.org/iso/iso_3166_code_lists).
 *
 * This utility should be run before mapping data on Blank-MapWorld6.svg 
 * (see http://commons.wikimedia.org/wiki/File:BlankMap-World6.svg).
 *
 * @author kvlinden
 * @version Fall, 2009
 */

String[] countryLines, isoCountryCodes, isoCountryNames;
String[] expectancyLines;
String[] aLine;

void setup() {
  loadISOCountryCodes("countryCodes.txt");
  loadExpectancyData("expectancy.txt");
  saveStrings("data/expectancyISO.txt", expectancyLines);
  println("finis");
  noLoop();
}

void loadISOCountryCodes(String filename) {
  countryLines = loadStrings(filename);
  isoCountryCodes = new String[countryLines.length];
  isoCountryNames = new String[countryLines.length];
  for (int i = 0; i < countryLines.length; i++) {
    isoCountryCodes[i] = countryLines[i].substring(0,2);
    isoCountryNames[i] = countryLines[i].substring(3, countryLines[i].length());
  }
}

void loadExpectancyData(String filename) {
  expectancyLines = loadStrings(filename);
  String country;
  for (int i = 0; i < expectancyLines.length; i++) {
    country = expectancyLines[i].substring(7, expectancyLines[i].length());
    expectancyLines[i] = findCountryCode(country) + " " + expectancyLines[i].substring(0, 6);
  }
}

String findCountryCode(String countryName) {
  for (int i = 0; i < isoCountryNames.length; i++) {
    if (isoCountryNames[i].equals(countryName)) {
      return isoCountryCodes[i];
    }
  }
  return countryName;
}







