/**
 * ExpectancyChart displays a simple bar graph of part of GapMinder's life-expectancy 
 * data for 2007 (see http://www.gapminder.org/gapminder-world/documentation/). With
 * some reprogramming, it can read its data from a file.
 *
 * @author kvlinden
 * @version Fall, 2009 
 */

float[] expectancyValues;
String[] expectancyLines, expectancyCountries;
String year, source;
//String[] expectancyCountries = { "China", "France", "Russia", "UK", "USA" };
//float[] expectancyValues = { 72.961, 80.657, 65.475, 79.425, 78.242 };
//String year = "2007";

int barHeight = 25, barWidthUnit = 3, labelWidth = 50, maximumAge = 90, headerSize = 25, footerSize = 100;
int width, height;
PFont headerFont, font;

void setup() {
  loadExpectancyData("expectancy.txt");
  width = barWidthUnit * maximumAge + labelWidth + 1;
  height = barHeight * expectancyValues.length + footerSize;
  size(width, height);
  headerFont = loadFont("Calibri-Bold-14.vlw");
  font = loadFont("Calibri-12.vlw");
  background(255);
  noLoop();
}

void draw() {
  drawHeader("Average Life Expectancy in Years (" + year + ")");
  //drawHeader("Average Life Expectancy in Years");
  drawBarGraph(expectancyValues, expectancyCountries);
  drawSummaryStatistics(expectancyValues);
}

void drawHeader(String headerText) {
  textFont(headerFont);
  fill(0);
  textAlign(LEFT, TOP);
  text(headerText, 10, 5);
}

void drawBarGraph(float[] values, String[] labels) {
  textFont(font);
  textAlign(RIGHT, TOP);
  for (int i = 0; i < values.length; i++) {
    // Draw the bar
    fill(234, 189, 90);
    rect(labelWidth, i * barHeight + headerSize, values[i] * barWidthUnit, barHeight);
    // Write the label and numeric value.
    fill(0);
    text(labels[i], labelWidth - 5, i * barHeight + 5 + headerSize);
    text(values[i], labelWidth + values[i] * barWidthUnit - 5, i * barHeight + 5 + headerSize);
  }
}

void drawSummaryStatistics(float[] values) {
  textFont(font);
  fill(0);
  textAlign(LEFT, TOP);
  text("Average: " + computeAverage(values), labelWidth, height - footerSize + headerSize + 12);
  text("Maximum Value: " + computeMaximum(values), labelWidth, height - footerSize + headerSize + 24);
  text("Minimum Value: " + computeMinimum(values), labelWidth, height - footerSize + headerSize + 36);
  text("Data Source: " + source, labelWidth, height - footerSize + headerSize + 55);
}

float computeAverage(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float sum = 0.0;
  for (int i = 0; i < values.length; i++) {
    sum += values[i];
  }
  return sum / values.length;
}

float computeMaximum(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float maximum = Integer.MIN_VALUE;
  for (int i = 0; i < values.length; i++) {
    if (values[i] > maximum) {
      maximum = values[i];
    }
  }
  return maximum;
}

float computeMinimum(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float minimum = Integer.MAX_VALUE;
  for (int i = 0; i < values.length; i++) {
    if (values[i] < minimum) {
      minimum = values[i];
    }
  }
  return minimum;
}

void loadExpectancyData(String filename) {
  expectancyLines = loadStrings(filename);
  expectancyCountries = new String[expectancyLines.length - 2];
  expectancyValues = new float[expectancyLines.length - 2];
  String[] tokens;
  year = expectancyLines[0];
  source = expectancyLines[1];
  for (int i = 2; i < expectancyLines.length; i++) {
    tokens = split(expectancyLines[i], " ");
    expectancyCountries[i - 2] = tokens[0];
    expectancyValues[i - 2] = float(tokens[1]);
  }
}

void keyPressed() {
  save("../../../../text/c06arrays/chart.tif");
}
















