/**
 * ExpectancyChartAnimation displays an animated bar graph of part of GapMinder's 
 * life-expectancy data for 2007 (see http://www.gapminder.org/gapminder-world/documentation/).
 *
 * @author kvlinden
 * @version Fall, 2009 
 */

String[] expectancyLines, expectancyCountries, expectancyYears;
float[][] expectancyValues;
String source = "GapMinder.com, 2009";
//String[] expectancyCountries = { "Ethiopia", "Kenya", "Rwanda", "Somalia", "Sudan", "Uganda" },
//         expectancyYears = { "1967", "1972", "1977", "1982", "1987", "1992", "1997", "2002", "2007" };
//float[][] expectancyValues = { 
//                            { 42.115, 50.654, 44.100, 38.977, 42.858, 48.051 }, // 1967
//                            { 43.515, 53.559, 44.600, 40.973, 45.083, 51.016 }, // 1972
//                            { 44.510, 56.155, 45.000, 41.974, 47.800, 50.350 }, // 1977
//                            { 44.916, 58.766, 46.218, 42.955, 50.338, 49.849 }, // 1982
//                            { 46.684, 59.339, 44.020, 44.501, 51.744, 51.509 }, // 1987
//                            { 48.091, 59.285, 23.599, 39.658, 53.556, 48.825 }, // 1992
//                            { 49.402, 54.407, 36.087, 43.795, 55.373, 44.578 }, // 1997
//                            { 50.725, 50.992, 43.413, 45.936, 56.369, 47.813 }, // 2002
//                            { 52.947, 54.110, 46.242, 48.159, 58.556, 51.542 }  // 2007
//                           };

int barHeight = 25, barWidthUnit = 3, labelWidth = 50, maximumAge = 90, headerSize = 25, footerSize = 100;
int width, height, frameCount;
PFont headerFont, font;

void setup() {
  loadExpectancyData("expectancyValues.txt", "expectancyCountries.txt", "expectancyYears.txt");
  width = barWidthUnit * maximumAge + labelWidth + 1;
  height = barHeight * expectancyCountries.length + footerSize;
  size(width, height);
  headerFont = loadFont("Calibri-Bold-14.vlw");
  font = loadFont("Calibri-12.vlw");
  frameRate(1);
  frameCount = 0;
}

void draw() {
  background(255);
  drawHeader("Average Life Expectancy in Years (" + expectancyYears[frameCount] + ")");
  //drawHeader("Average Life Expectancy in Years");
  drawBarGraph(expectancyValues[frameCount], expectancyCountries);
  drawSummaryStatistics(expectancyValues[frameCount]);
  frameCount++;
  if (frameCount >= expectancyYears.length) {
    noLoop();
  }
  saveFrame("../../../../text/c06arrays/expectancyFrames/chart-###.tif");
}

void drawHeader(String headerText) {
  textFont(headerFont);
  fill(0);
  textAlign(LEFT, TOP);
  text(headerText, 10, 5);
}

void drawBarGraph(float[] values, String[] labels) {
  textFont(font);
  textAlign(RIGHT, TOP);
  for (int i = 0; i < values.length; i++) {
    // Draw the bar
    fill(234, 189, 90);
    rect(labelWidth, i * barHeight + headerSize, values[i] * barWidthUnit, barHeight);
    // Write the label and numeric value.
    fill(0);
    text(labels[i], labelWidth - 5, i * barHeight + 5 + headerSize);
    text(values[i], labelWidth + values[i] * barWidthUnit - 5, i * barHeight + 5 + headerSize);
  }
}

void drawSummaryStatistics(float[] values) {
  textFont(font);
  fill(0);
  textAlign(LEFT, TOP);
  text("Average: " + computeAverage(values), labelWidth, height - footerSize + headerSize + 12);
  text("Maximum Value: " + computeMaximum(values), labelWidth, height - footerSize + headerSize + 24);
  text("Minimum Value: " + computeMinimum(values), labelWidth, height - footerSize + headerSize + 36);
  text("Data Source: " + source, labelWidth, height - footerSize + headerSize + 55);
}

float computeAverage(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float sum = 0.0;
  for (int i = 0; i < values.length; i++) {
    sum += values[i];
  }
  return sum / values.length;
}

float computeMaximum(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float maximum = Integer.MIN_VALUE;
  for (int i = 0; i < values.length; i++) {
    if (values[i] > maximum) {
      maximum = values[i];
    }
  }
  return maximum;
}

float computeMinimum(float[] values) {
  if ((values == null) || (values.length <= 0)) {
    return 0.0;
  }
  float minimum = Integer.MAX_VALUE;
  for (int i = 0; i < values.length; i++) {
    if (values[i] < minimum) {
      minimum = values[i];
    }
  }
  return minimum;
}

void loadExpectancyData(String valuesFilename, String countriesFilename, String yearsFilename) {
  expectancyCountries = loadStrings(countriesFilename);
  expectancyYears = loadStrings(yearsFilename);
  expectancyLines = loadStrings(valuesFilename);
  expectancyValues = new float[expectancyLines.length][expectancyCountries.length];
  String[] tokens;
  for (int i = 0; i < expectancyLines.length; i++) {
    tokens = split(expectancyLines[i], " ");
    for (int j = 0; j < tokens.length; j++) {
      expectancyValues[i][j] = float(tokens[j]);
    }
  }


  //  println("Average Life Expectancy by Year and Country");
  //  print("\t");
  //  for (int i = 0; i < expectancyCountries.length; i++) {
  //    print(expectancyCountries[i] + "\t");
  //  }
  //  println();
  //  for (int i = 0; i < expectancyValues.length; i++) {
  //    print(expectancyYears[i] + "\t");
  //    for (int j = 0; j < expectancyValues[0].length; j++) {
  //      print(expectancyValues[i][j] + "\t");
  //    }
  //    println();
  //  }
}




