/**
 * ExpectancyMap displays the world with color based on average life-expectancy 
 * data from GapMinder.
 *
 * data: http://www.gapminder.org/gapminder-world/documentation/
 * world image: http://commons.wikimedia.org/wiki/File:BlankMap-World6.svg
 * country codes: see http://www.iso.org/iso/iso_3166_code_lists
 *
 * @author: kvlinden
 * @version Fall, 2009
 */

PShape world, country;
String[] expectancyLines, expectancyCountries;
float[] expectancyValues;
float maximumExpectancy, minimumExpectancy;

void setup() {
  size(1125, 590);
  world = loadShape("BlankMap-World6-small.svg");
//  world.disableStyle();
  loadExpectancyData("expectancyISO.txt");
  smooth();
  noLoop();
}

void draw() {
  background(255);
  shape(world);
  float intensityValue;
  for (int i = 0; i < expectancyCountries.length; i++) {
    country = world.getChild(expectancyCountries[i].toLowerCase());
    if (country != null) {
      country.disableStyle();
      intensityValue = map(expectancyValues[i], minimumExpectancy, maximumExpectancy, 0, 255);
      fill(255 - intensityValue, 255 - intensityValue, 255);
      shape(country);
    }
  }
}

void loadExpectancyData(String filename) {
  String[] aLine;
  expectancyLines = loadStrings(filename);
  expectancyCountries = new String[expectancyLines.length];
  expectancyValues = new float[expectancyLines.length];
  maximumExpectancy = Integer.MIN_VALUE;
  minimumExpectancy = Integer.MAX_VALUE;
  for (int i = 0; i < expectancyLines.length; i++) {
    aLine = split(expectancyLines[i], " ");
    expectancyCountries[i] = aLine[0];
    expectancyValues[i] = float(aLine[1]);
    if (expectancyValues[i] > maximumExpectancy) {
      maximumExpectancy = expectancyValues[i];
    }
    if (expectancyValues[i] < minimumExpectancy) {
      minimumExpectancy = expectancyValues[i];
    }
  }
  println("max: " + maximumExpectancy + " min: " + minimumExpectancy);
}

void keyPressed() {
  save("../../../../text/c06arrays/world.tif");
}











