/**
 * ExpectancyTable displays a textual table of part of GapMinder's life-expectancy 
 * data for 2007 (see http://www.gapminder.org/gapminder-world/documentation/). With
 * some reprogramming, it can read its data from a file.
 *
 * @author kvlinden
 * @version Spring, 2010
 */

// For hard-coded values.
//String[] expectancyCountries = { 
//  "China", "France", "Russia", "UK", "USA" };
//float[] expectancyValues = { 
//  72.961, 80.657, 65.475, 79.425, 78.242 };
//String year = "2007", source = "GapMinder.com, 2009";

// For file-based data
String filename = "expectancy.txt";
String[] expectancyLines, expectancyCountries;
float[] expectancyValues;
String year, source;

// Load the data from a file
expectancyLines = loadStrings(filename);
expectancyCountries = new String[expectancyLines.length - 2];
expectancyValues = new float[expectancyLines.length - 2];
String[] tokens;
year = expectancyLines[0];
source = expectancyLines[1];
for (int i = 2; i < expectancyLines.length; i++) {
  tokens = split(expectancyLines[i], " ");
  expectancyCountries[i - 2] = tokens[0];
  expectancyValues[i - 2] = float(tokens[1]);
}

// Print the table header.
println("Average Life Expectancy in Years (" + year + ")");

// Initialize the aggregator values.
float sum = 0.0, maximum = Float.MIN_VALUE, minimum = Float.MAX_VALUE;

for (int i = 0; i < expectancyCountries.length; i++) {
  // Print the next table row.
  print(expectancyCountries[i] + ": " + expectancyValues[i] + "\n");

  // Accumulate the sum of the expectancy values.
  sum += expectancyValues[i];

  // Update the maximum value seen so far.
  if (expectancyValues[i] > maximum) {
    maximum = expectancyValues[i];
  }

  // Update the minimum value seen so far.
  if (expectancyValues[i] < minimum) {
    minimum = expectancyValues[i];
  }
}

// Print the aggregate statistics.
println("Average: " + sum / expectancyCountries.length);
println("Maximum Value: " + maximum);
println("Minimum Value: " + minimum);
println("Data Source: " + source);





