/**
 * Ball implements a simple pinball. It extends the text example by adding movement and bouncing.
 *
 * @author kvlinden
 * @version Fall, 2009
 */

class Ball {
  
  private float myX, myY, myDiameter, myVelocityX, myVelocityY, myAccelerationX, myAccelerationY;
  private color myColor;
  
  public Ball(float x, float y, float diameter, float velocityX, float velocityY, float accelerationX, float accelerationY) {
    myX = x;
    myY = y;
    myDiameter = constrain(diameter, 0, MAX_INT);
    myVelocityX = velocityX;
    myVelocityY = velocityY;
    myAccelerationX = accelerationX;
    myAccelerationY = accelerationY;
    myColor = color(random(255), random(255), random(255));
  }
  
  public void render() {
    stroke(0);
    fill(myColor);
    ellipse(myX, myY, myDiameter, myDiameter);
  }
  
  public void move(Paddle paddle) {
    myX += myVelocityX;
    myY += myVelocityY;
    if (hitsSide()) {
      myVelocityX *= -1;
      myAccelerationX *= -1;
    }
    if (hitsBottom() && hitsPaddle(paddle)) {
      myY = height - myDiameter/2 - paddle.getHeight();
      myVelocityY *= -1;
    }
    if (abs(myVelocityX) < 0.01) {
      myVelocityX = 0.0;
    }
    myVelocityX += myAccelerationX;
    myVelocityY += myAccelerationY;
  }
  
  // determines if this ball has hit the side of the display
  private boolean hitsSide() {
    return (myX - myDiameter/2 <= 0) || (myX + myDiameter/2 >= width);
  }
  
  private boolean hitsBottom() {
    return abs(myY + myDiameter/2 + paddle.getHeight() - height) <= myVelocityY;
  }
  
  private boolean hitsPaddle(Paddle paddle) {
    return abs(myX - paddle.getX()) < (paddle.getWidth() / 2);
  }
  
}

