class SimpleBall {

  private float myX, myY, myVelocityX, myVelocityY;
  private int myDiameter;
  private color myColor;

  public SimpleBall() {
    myX = myY = 50.0;
    myVelocityX = myVelocityY = 0.0;
    myDiameter = 25;
    myColor = color(255);
  }

  // Constructor for stationary balls
  public SimpleBall(float x, float y, int diameter) {
    myX = x;
    myY = y;
    myVelocityX = myVelocityY = 0.0;
    myDiameter = constrain(diameter, 1, MAX_INT);
    myColor = color(random(255), random(255), random(255));
  }

  public SimpleBall(float x, float y, int diameter, float velocityX, float velocityY) {
    myX = constrain(x, 0, MAX_INT);
    myY = constrain(y, 0, MAX_INT);
    myDiameter = constrain(diameter, 0, MAX_INT);
    myVelocityX = velocityX;
    myVelocityY = velocityY;
    myColor = color(255);
  }

  public float getX() {
    return myX;
  }
  public float getY() {
    return myY;
  }
  public int getDiameter() {
    return myDiameter;
  }
  public void setDiameter(int diameter) {
    myDiameter = constrain(diameter, 0, MAX_INT);
  }

  public color getColor() {
    return myColor;
  }
  public void setColor(color c) {
    myColor = c;
  }

  public void render() {
    stroke(0);
    fill(myColor);
    ellipse(myX, myY, myDiameter, myDiameter);
  }

  public void move() {
    myX += myVelocityX;
    myY += myVelocityY;
  }

  public boolean hits(SimpleBall otherBall) {
    return (myDiameter/2 + otherBall.getDiameter()/2) >= dist(myX, myY, otherBall.getX(), otherBall.getY());
  }

  // Collision algorithm based on K. Terzidis, Algorithms for Visual Design
  public void collide(SimpleBall otherBall) {
    float angle = atan2(otherBall.getY() - myY, otherBall.getX() - myX);
    float otherBallX = myX + cos(angle) * (myDiameter/2 + otherBall.getDiameter()/2);
    float otherBallY = myY + sin(angle) * (myDiameter/2 + otherBall.getDiameter()/2);
    float ax = (otherBallX - otherBall.getX());
    float ay = (otherBallY - otherBall.getY());
    myVelocityX = (myVelocityX - ax);
    myVelocityY = (myVelocityY - ay);   
  }


}





