package c10quality.text.temperatureEnumeration;

import static c10quality.text.temperatureEnumeration.Temperature.Scale.CELSIUS;
import static c10quality.text.temperatureEnumeration.Temperature.Scale.FAHRENHEIT;
import static c10quality.text.temperatureEnumeration.Temperature.Scale.KELVIN;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotSame;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import org.junit.Test;

import c10quality.text.temperatureEnumeration.Temperature.Scale;

/**
 * Unit tests for the temperature class for Chapter 10 (and 9).
 * 
 * @author kvlinden
 * @version Spring, 2012
 */
public class TemperatureTest {

	@Test
	public void defaultConstructorTests() {
		Temperature t1 = new Temperature();
		assertEquals(0.0, t1.getDegrees(), 1e-5);
		assertEquals(CELSIUS, t1.getScale());
	}

	@Test
	public void explicitValueConstructorTests() {
		try {
			Temperature t1 = new Temperature(0, KELVIN);
			assertEquals(0.0, t1.getDegrees(), 1e-5);
			assertEquals(KELVIN, t1.getScale());

			t1 = new Temperature(98.6, FAHRENHEIT);
			assertEquals(98.6, t1.getDegrees(), 1e-5);
			assertEquals(FAHRENHEIT, t1.getScale());
		} catch (Exception e) {
			fail("inappropriate exception raised...");
		}
	}

	@Test
	public void badExplicitValueConstructorTests() {
		// badExplicitValueConstructorUtility(10.0, 'X');
		badExplicitValueConstructorUtility(-0.01, KELVIN);
	}

	private void badExplicitValueConstructorUtility(double degrees, Scale scale) {
		Temperature t;
		try {
			t = new Temperature(degrees, scale);
			fail("Exception should have been thrown on: " + degrees + " " + scale);
		} catch (Exception e) {
			// Do nothing; it should throw this exception.
		}
	}

	@Test
	public void equalityTests() {
		Temperature t;
		try {
			// Test freezing temperature equivalents.
			t = new Temperature(0.0, CELSIUS);
			t.setScale(FAHRENHEIT);
			assertEquals(32.0, t.getDegrees(), 1e-5);
			t.setScale(KELVIN);
			assertEquals(273.15, t.getDegrees(), 1e-5);

			// Test boiling temperature equivalents.
			t = new Temperature(373.15, KELVIN);
			t.setScale(FAHRENHEIT);
			assertEquals(212.0, t.getDegrees(), 1e-5);
			t.setScale(CELSIUS);
			assertEquals(100.0, t.getDegrees(), 1e-5);

			// Test absolute zero temperature equivalents.
			t = new Temperature(-459.67, FAHRENHEIT);
			t.setScale(KELVIN);
			assertEquals(0.0, t.getDegrees(), 1e-5);
			t.setScale(CELSIUS);
			assertEquals(-273.15, t.getDegrees(), 1e-5);

			// Test large temperature equivalents.
			t = new Temperature(1799540.33, FAHRENHEIT);
			t.setScale(CELSIUS);
			assertEquals(999726.85, t.getDegrees(), 1e-5);
			t.setScale(KELVIN);
			assertEquals(1000000.0, t.getDegrees(), 1e-5);
		} catch (Exception e) {
			fail("inappropriate exception raised...");
		}
	}

	@Test
	public void comparatorsTest() {
		Temperature t1;
		try {
			t1 = new Temperature(5.0, KELVIN);
			assertTrue(t1.equals(t1));
			assertFalse(t1.lessThan(t1));
			assertTrue(t1.lessThanOrEqualTo(t1));
			assertFalse(t1.greaterThan(t1));
			assertTrue(t1.greaterThanOrEqualTo(t1));
			Temperature t2 = new Temperature(25.0, CELSIUS);
			assertFalse(t1.equals(t2));
			assertTrue(t1.lessThan(t2));
			assertFalse(t1.greaterThan(t2));
			assertTrue(t1.lessThanOrEqualTo(t2));
			assertFalse(t1.greaterThanOrEqualTo(t2));
			Temperature t3 = new Temperature(5.0, FAHRENHEIT);
			assertFalse(t1.equals(t3));
			assertTrue(t1.lessThan(t3));
			assertTrue(t1.lessThanOrEqualTo(t3));
			assertFalse(t1.greaterThan(t2));
			assertFalse(t1.greaterThanOrEqualTo(t3));
		} catch (Exception e) {
			fail("inappropriate exception thrown...");
		}
	}

	@Test
	public void changeTests() {
		try {
			Temperature t1 = new Temperature(50.0, FAHRENHEIT);
			t1.change(10.0);
			assertEquals(60.0, t1.getDegrees(), 0e-5);
			t1.change(-20.0);
			assertEquals(40.0, t1.getDegrees(), 0e-5);
		} catch (Exception e) {
			fail("inappropriate exception raised...");
		}
	}

	public void testCopy() {
		Temperature t1;
		try {
			t1 = new Temperature(10000.5, CELSIUS);
			Temperature t2 = t1.copy();
			assertTrue(t1.equals(t2));
			assertNotSame(t1, t2);
		} catch (Exception e) {
			fail("inappropriate exception raised...");
		}
	}

}
