package c10quality.text.temperatureGUI;

import java.awt.Color;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.DecimalFormat;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

public class Temperature1ConverterController extends JFrame implements
		ActionListener {

	private JTextField celsiusField, fahrenheitField, kelvinField;
	private JLabel messageLabel;

	public Temperature1ConverterController() {
		setTitle("Temperature Converter");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		setLayout(new GridLayout(4, 1));
		Font font = new Font("Ariel", 0, 18);
		celsiusField = new JTextField(7);
		add(createTemperatureControl("Celsius", celsiusField, font));
		fahrenheitField = new JTextField(7);
		add(createTemperatureControl("Fahrenheit", fahrenheitField, font));
		kelvinField = new JTextField(7);
		add(createTemperatureControl("Kelvin", kelvinField, font));
		messageLabel = new JLabel("Please enter a temperature.");
		add(messageLabel);
	}

	private JPanel createTemperatureControl(String name, JTextField field,
			Font font) {
		JPanel panel = new JPanel();
		panel.setLayout(new GridLayout(1, 2));
		JLabel label = new JLabel(name + ": ", JLabel.RIGHT);
		label.setFont(font);
		panel.add(label);
		field.setFont(font);
		field.setActionCommand(name);
		field.addActionListener(this);
		panel.add(field);
		return panel;
	}

	@Override
	public void actionPerformed(ActionEvent ae) {
		String actionEvent = ae.getActionCommand();
		Temperature1 temperature;
		double degrees;
		try {
			if (actionEvent.equalsIgnoreCase("celsius")) {
				degrees = Double.parseDouble(celsiusField.getText());
			} else if (actionEvent.equalsIgnoreCase("fahrenheit")) {
				degrees = Double.parseDouble(fahrenheitField.getText());
			} else {
				degrees = Double.parseDouble(kelvinField.getText());
			}
			temperature = new Temperature1(degrees, ae.getActionCommand());
			setFieldColor(Color.WHITE);
			setTextFields(temperature);
			messageLabel.setText("success...");
		} catch (NumberFormatException e) {
			setFieldColor(Color.CYAN);
			messageLabel.setText("Illegal format: " + e.getMessage());
		} catch (Exception e) {
			setFieldColor(Color.YELLOW);
			messageLabel.setText(e.getMessage());
		}
	}

	private void setFieldColor(Color color) {
		celsiusField.setBackground(color);
		fahrenheitField.setBackground(color);
		kelvinField.setBackground(color);
	}

	private void setTextFields(Temperature1 temperature) throws Exception {
		temperature.setScale("celsius");
		celsiusField.setText(doubleToString(temperature.getDegrees()));
		temperature.setScale("fahrenheit");
		fahrenheitField.setText(doubleToString(temperature.getDegrees()));
		temperature.setScale("kelvin");
		kelvinField.setText(doubleToString(temperature.getDegrees()));

	}

	private String doubleToString(double value) {
		DecimalFormat doubleFormat = new DecimalFormat("#.##");
		return doubleFormat.format(value);
	}

	public static void main(String[] args) {
		Temperature1ConverterController controller = new Temperature1ConverterController();
		controller.pack();
		controller.setVisible(true);
	}

}
