package c10quality.text.temperatureGUI;

import static c10quality.text.temperatureGUI.Temperature2.Scale.*;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotSame;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import org.junit.Test;

import c10quality.text.temperatureGUI.Temperature2.Scale;

public class Temperature2Test {

	private static final double DOUBLE_EPSILON = 1e-3;

	@Test
	public void doNothingTest() {
		assertTrue(true);
		assertEquals(false, false);
	}

	@Test
	public void defaultConstructorTest() {
		Temperature2 t = new Temperature2();
		assertEquals(0.0, t.getDegrees(), DOUBLE_EPSILON);
		assertEquals(CELSIUS, t.getScale());
	}

	@Test
	public void explicitConstructorTest() {
		Temperature2 t = new Temperature2(0.0, CELSIUS);
		assertEquals(0.0, t.getDegrees(), DOUBLE_EPSILON);
		assertEquals(CELSIUS, t.getScale());

		t = new Temperature2(273.15, KELVIN);
		assertEquals(273.15, t.getDegrees(), DOUBLE_EPSILON);
		assertEquals(KELVIN, t.getScale());

		t = new Temperature2(32.0, FAHRENHEIT);
		assertEquals(32.0, t.getDegrees(), DOUBLE_EPSILON);
		assertEquals(FAHRENHEIT, t.getScale());

		badTemperatureConstructionUtility(-1.0, KELVIN);
		badTemperatureConstructionUtility(-274.0, CELSIUS);
		badTemperatureConstructionUtility(-460.0, FAHRENHEIT);

		goodTemperatureConstructionUtility(10000.5, CELSIUS);
		goodTemperatureConstructionUtility(10000.5, FAHRENHEIT);
		goodTemperatureConstructionUtility(10000.5, KELVIN);

		// The compiler will not allow us to specify an invalid temperature
		// scale name, so we can
		// only test the invalid temperature scale thrown error by adding a
		// new/invalid static scale
		// constant.

	}

	private void goodTemperatureConstructionUtility(double degrees, Scale scale) {
		Temperature2 t = new Temperature2(degrees, scale);
	}

	private void badTemperatureConstructionUtility(double degrees, Scale scale) {
		try {
			@SuppressWarnings("unused")
			Temperature2 t = new Temperature2(degrees, scale);
			fail("in appropriately constructed a " + degrees + " degree " + scale + " Temperature");
		} catch (IllegalArgumentException e) {
			// It should throw this exception!
		}
	}

	@Test
	public void mutatorTest() {
		Temperature2 t = new Temperature2();
		t.setScale(FAHRENHEIT);
		assertEquals(32.0, t.getDegrees(), DOUBLE_EPSILON);
		t.setScale(KELVIN);
		assertEquals(273.15, t.getDegrees(), DOUBLE_EPSILON);

		t = new Temperature2(373.15, KELVIN);
		t.setScale(FAHRENHEIT);
		assertEquals(212.0, t.getDegrees(), DOUBLE_EPSILON);
		t.setScale(CELSIUS);
		assertEquals(100.0, t.getDegrees(), DOUBLE_EPSILON);

		t = new Temperature2(-273.15, CELSIUS);
		t.setScale(FAHRENHEIT);
		assertEquals(-459.67, t.getDegrees(), DOUBLE_EPSILON);
		t.setScale(KELVIN);
		assertEquals(0.0, t.getDegrees(), DOUBLE_EPSILON);

		t = new Temperature2(1799540.33, FAHRENHEIT);
		t.setScale(CELSIUS);
		assertEquals(999726.85, t.getDegrees(), DOUBLE_EPSILON);
		t.setScale(KELVIN);
		assertEquals(1000000.0, t.getDegrees(), DOUBLE_EPSILON);
	}

	@Test
	public void comparatorsTest() {
		Temperature2 t1 = new Temperature2(5.0, KELVIN);
		assertTrue(t1.equals(t1));
		assertFalse(t1.lessThan(t1));
		assertTrue(t1.lessThanOrEquals(t1));
		assertFalse(t1.greaterThan(t1));
		assertTrue(t1.greaterThanOrEquals(t1));
		Temperature2 t2 = new Temperature2(25.0, CELSIUS);
		assertFalse(t1.equals(t2));
		assertTrue(t1.lessThan(t2));
		assertFalse(t1.greaterThan(t2));
		assertTrue(t1.lessThanOrEquals(t2));
		assertFalse(t1.greaterThanOrEquals(t2));
		Temperature2 t3 = new Temperature2(5.0, FAHRENHEIT);
		assertFalse(t1.equals(t3));
		assertTrue(t1.lessThan(t3));
		assertTrue(t1.lessThanOrEquals(t3));
		assertFalse(t1.greaterThan(t2));
		assertFalse(t1.greaterThanOrEquals(t3));
	}

	public void testCopy() {
		Temperature2 t1 = new Temperature2(10000.5, CELSIUS);
		Temperature2 t2 = t1.copy();
		assertTrue(t1.equals(t2));
		assertNotSame(t1, t2);
	}

}
