package c11ui.text.raindrops.raindrops2;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;


/**
 * RaindropController1 shows a raindrops animation with the ability to set the
 * frame rate.
 * 
 * @author kvlinden
 * @version Fall, 2009
 * @version upgraded for inner classes Spring, 2012
 */
@SuppressWarnings("serial")
public class RaindropController extends JFrame {

	private static int DEFAULT_FRAMERATE = 30;
	
	private RaindropPanel raindropPanel;
	private JButton startButton, pauseButton;
	private JTextField frameRateField, outputField;

	public RaindropController() {
		setTitle("Raindrops");
		setDefaultCloseOperation(EXIT_ON_CLOSE);		

		// the raindrop animation panel
		try {
			raindropPanel = new RaindropPanel(DEFAULT_FRAMERATE);
		} catch (Exception e) {
			// This should never happen.
			outputField.setText("Invalid rate: " + DEFAULT_FRAMERATE);			
		}
		raindropPanel.init();
		add(raindropPanel, BorderLayout.NORTH);

		// a single framerate field version
		// frameRateField = new JTextField(3);
		// frameRateField.setText("30");
		// //frameRateField.setFont(new Font("Ariel", 0, 20));
		// frameRateField.addActionListener(this);
		// add(frameRateField, BorderLayout.SOUTH);

		// a control panel
		JPanel controlPanel = new JPanel(new FlowLayout());
		startButton = new JButton("Start");
		startButton.setEnabled(false);
		startButton.addActionListener(new StartButtonListener());
		controlPanel.add(startButton);
		pauseButton = new JButton("Pause");
		pauseButton.setEnabled(true);
		pauseButton.addActionListener(new PauseButtonListener());
		controlPanel.add(pauseButton);
		controlPanel.add(new JLabel("Frame rate:"));
		frameRateField = new JTextField(3);
		frameRateField.setText("30");
		controlPanel.add(frameRateField);
		frameRateField.addActionListener(new RateFieldListener());
		add(controlPanel, BorderLayout.CENTER);

		outputField = new JTextField("Welcome to the raindrops controller.");
		outputField.setEditable(false);
		add(outputField, BorderLayout.SOUTH);
	}

	class StartButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			// Handle the start operation.
			raindropPanel.setRunning(true);
			startButton.setEnabled(false);
			pauseButton.setEnabled(true);
		}
	}

	class PauseButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			// Handle the pause operation.
			raindropPanel.setRunning(false);
			startButton.setEnabled(true);
			pauseButton.setEnabled(false);
		}
	}

	class RateFieldListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			// Handle rate entry.
			String frameRateString = frameRateField.getText();
			try {
				int newFrameRate = Integer.parseInt(frameRateString);
				raindropPanel.setFrameRate(newFrameRate);
			} catch (Exception e) {
				outputField.setText("Invalid rate: " + frameRateString);
			}
		}
	}

	public static void main(String[] args) {
		RaindropController controller = new RaindropController();
		controller.pack();
		controller.setVisible(true);
	}

}
