package c12lists.lecture.students;

import java.util.Scanner;

/**
 * Student models a university student.
 * 
 * class invariant: myYear is "freshman" || "sophomore" || "junior" || "senior"
 * || "graduate"
 * 
 * @author kvlinden
 * @version based on original text implementation, Spring, 2012
 */
class Student {

	private int myID;
	private String myFirstName, myLastName, myYear;
	private double myCredits, myGPA;

	/**
	 * This constructor creates an "empty" student record.
	 */
	public Student() {
		myID = 0;
		myFirstName = myLastName = myYear = "";
		myCredits = myGPA = 0.0;
	}

	/**
	 * This constructor creates a new student based on the given string. The
	 * string must contain student information in the appropriate format (i.e.,
	 * ID#, first name, last name, class level, credits and GPA).
	 * 
	 * All field values are assumed to be single "words", so no spaces are
	 * allowed in last names. Any parsing problems throw exceptions.
	 * 
	 * @param line
	 *            the student's information is textual form
	 * @throws Exception
	 */
	public Student(String line) throws Exception {
		Scanner lineScanner = new Scanner(line);
		myID = lineScanner.nextInt();
		if (myID < 0) {
			throw new Exception("Invalid id number: " + myID);
		}

		myFirstName = lineScanner.next();
		myLastName = lineScanner.next();

		myYear = lineScanner.next();
		if (!isValidYear(myYear)) {
			throw new Exception("Invalid year entry: " + myYear);
		}

		myCredits = lineScanner.nextDouble();
		if (myCredits < 0.0) {
			throw new Exception("Invalid credits entry: " + myCredits);
		}

		myGPA = lineScanner.nextDouble();
		if (myGPA < 0.0 || myGPA > 5.0) {
			throw new Exception("Invalid credits entry: " + myGPA);
		}
		
		if (lineScanner.hasNext()) {
			throw new Exception("too many tokens on line: " + line);
		}
	}

	// Check the class invariant.
	private boolean isValidYear(String year) {
		return year.equalsIgnoreCase("freshman") || year.equalsIgnoreCase("sophomore")
				|| year.equalsIgnoreCase("junior") || year.equalsIgnoreCase("senior")
				|| year.equalsIgnoreCase("graduate");
	}

	public int getIdNumber() {
		return myID;
	}

	public String getFirstName() {
		return myFirstName;
	}

	public String getLastName() {
		return myLastName;
	}

	public String getYear() {
		return myYear;
	}

	public double getCredits() {
		return myCredits;
	}

	public double getGPA() {
		return myGPA;
	}

	@Override
	public String toString() {
		return "" + myID + " " + myFirstName + " " + myLastName + " " + myYear + " " + myCredits
				+ " " + myGPA;
	}
}
