package c12lists.text.characterdrill.characterdrill1;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * ChineseDrillController implements a simple Chinese character review
 * application. This version uses no images, sounds or Unicode strings.
 * 
 * @author kvlinden
 * @version Fall, 2009
 * @version Revised to remove file handling, Spring, 2012
 */
@SuppressWarnings("serial")
public class CharacterDrillController extends JFrame {

	private JLabel hintLabel;
	private JTextField guessField;
	private JButton giveupButton;
	private CharacterDrill drill;

	public CharacterDrillController() throws Exception {
		setTitle("Chinese Character Drill");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		Font font = new Font("Arial Unicode MS", 0, 24);

		drill = new CharacterDrill();

		JPanel guessController = new JPanel();
		guessController.setLayout(new FlowLayout());

		JLabel guessLabel = new JLabel("English: ");
		guessLabel.setFont(font);
		guessController.add(guessLabel);

		guessField = new JTextField(15);
		guessField.setFont(font);
		guessField.setActionCommand("Guess");
		guessField.addActionListener(new GuessFieldListener());
		guessController.add(guessField);

		giveupButton = new JButton("Give Up");
		giveupButton.setFont(font);
		giveupButton.addActionListener(new GiveupButtonListener());
		guessController.add(giveupButton);

		add(guessController, BorderLayout.SOUTH);

		hintLabel = new JLabel();
		hintLabel.setFont(font);
		hintLabel.setText(drill.getHintText());
		add(hintLabel, BorderLayout.CENTER);
	}

	class GuessFieldListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			try {
				if (drill.guess(guessField.getText())) {
					drill.reset();
					hintLabel.setText("Right! " + drill.getHintText());
				} else {
					hintLabel.setText("Guess again - " + drill.getHintText());
				}
				guessField.setText("");
			} catch (Exception e) {

			}
		}
	}

	class GiveupButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			try {
				String answer = drill.getAnswer();
				drill.reset();
				hintLabel.setText("Answer: " + answer + " - Next: " + drill.getHintText());
				guessField.setText("");
			} catch (Exception e) {

			}
		}
	}

	public static void main(String[] args) throws Exception {
		CharacterDrillController application = new CharacterDrillController();
		application.pack();
		application.setVisible(true);
	}

}
