package c12lists.text.characterdrill.characterdrill3;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URISyntaxException;

import javax.swing.*;

/**
 * ChineseDrillController implements a simple Chinese character review
 * application. This version adds audio support and the file dialog box.
 * 
 * The CharacterDrillPanel requires Minim; find the *.jar files for this package
 * in the standard course repository. It also requires that appropriately
 * configured data, image and audio files be stored in the data sub-directory.
 * 
 * @author kvlinden
 * @version Fall, 2009
 */
@SuppressWarnings("serial")
public class CharacterDrillController extends JFrame {

	private CharacterDrillPanel drillPanel;
	private JLabel hintLabel;
	private JTextField guessField;
	private JButton giveupButton;
	private CharacterDrill drill;

	public CharacterDrillController() throws Exception {
		setTitle("Character Character Drill");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		Font font = new Font("Arial Unicode MS", 0, 24);

		JFileChooser fileChooser = new JFileChooser();
		fileChooser.setDialogTitle("Choose an input filename");
		fileChooser.showSaveDialog(this);
		String path = fileChooser.getSelectedFile().getParent();
		drill = new CharacterDrill(path, fileChooser.getSelectedFile().getName());

		hintLabel = new JLabel();
		hintLabel.setFont(font);
		add(hintLabel, BorderLayout.CENTER);

		JPanel guessController = new JPanel();
		guessController.setLayout(new FlowLayout());
		JLabel guessLabel = new JLabel("PinYin: ");
		guessLabel.setFont(font);
		guessController.add(guessLabel);
		guessField = new JTextField(15);
		guessField.setFont(font);
		guessField.setActionCommand("Guess");
		guessField.addActionListener(new GuessFieldListener());
		guessController.add(guessField);
		giveupButton = new JButton("Give Up");
		giveupButton.setFont(font);
		giveupButton.addActionListener(new GiveupButtonListener());
		guessController.add(giveupButton);
		add(guessController, BorderLayout.SOUTH);

		hintLabel.setText(drill.getHintText());
		drillPanel = new CharacterDrillPanel(path+"/");
		drillPanel.init();
		add(drillPanel, BorderLayout.NORTH);
		initializeDrill();
	}

	class GuessFieldListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			try {
				if (drill.guess(guessField.getText())) {
					drill.reset();
					hintLabel.setText("Right! " + drill.getHintText());
					initializeDrill();
				} else {
					hintLabel.setText("Guess again - " + drill.getHintText());
				}
				guessField.setText("");
			} catch (Exception e) {

			}
		}
	}

	class GiveupButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent ae) {
			try {
				String answer = drill.getAnswer();
				drill.reset();
				hintLabel.setText("Answer: " + answer + " - Next: " + drill.getHintText());
				initializeDrill();
				guessField.setText("");
			} catch (Exception e) {

			}
		}
	}

	private void initializeDrill() throws URISyntaxException {
		drillPanel.setImage(drill.getHintImageFilename());
		drillPanel.setPronunciation(drill.getHintPronunciationFilename());
		drillPanel.playPronunciation();
	}

	public static void main(String[] args) throws Exception {
		CharacterDrillController application = new CharacterDrillController();
		application.pack();
		application.setVisible(true);
	}

}
