package c12lists.text.characterdrill.characterdrill3;

import java.net.URI;
import java.net.URISyntaxException;

import processing.core.PApplet;
import processing.core.PImage;
import ddf.minim.AudioSnippet;
import ddf.minim.Minim;

/**
 * CharacterDrillPanel supports the display of images and playing of audio clips
 * for the CharacterDrill application.
 * 
 * You must include the Minim audio libraries in your build path; find them in
 * the standard code repository.
 * 
 * Images taken from http://chineseculture.about.com
 * 
 * @author kvlinden
 * @version Fall, 2009
 */
public class CharacterDrillPanel extends PApplet {

	private String myPath;
	private PImage myImage;
	private int myTintValue;
	private Minim myMinim;
	private AudioSnippet myPronunciation;

	public CharacterDrillPanel(String path) {
		myPath = path;
		myMinim = new Minim(this);
	}

	public CharacterDrillPanel(String path, String imageFilename, String pronunciationFilename)
			throws URISyntaxException {
		myPath = path;
		setImage(imageFilename);
		myMinim = new Minim(this);
		setPronunciation(pronunciationFilename);
	}

	public void setImage(String filename) throws URISyntaxException {
		myImage = loadImage(myPath + filename);
		myTintValue = 0;
	}

	public void setPronunciation(String filename) {
		myPronunciation = myMinim.loadSnippet(myPath + filename);
	}

	public void playPronunciation() {
		myPronunciation.play();
	}

	public void setup() {
		size(300, 300);
		background(255);
		imageMode(CENTER);
	}

	public void draw() {
		if (myImage != null) {
			tint(255, myTintValue);
			image(myImage, width / 2, height / 2);
			myTintValue = constrain(myTintValue + 1, 0, 255);
		}
	}

	public void stop() {
		myPronunciation.close();
		myMinim.stop();
	}

}
