package c12lists.text.characterdrill.characterdrillOld;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.Scanner;

/**
 * CharacterDrill2 maintains the model for the character drill game. It supports
 * a hard-coded set of Chinese characters or a file-based solution.
 * 
 * @author kvlinden
 * @version Fall, 2009
 */
public class CharacterDrill2 {

	private List<Character> myCharacters;
	private int myAnswerIndex, myHintCount;

	private Random myRandom;

	public CharacterDrill2() {
		myCharacters = new ArrayList<Character>();
		myCharacters.add(new Character("I", "wo3", "wo3.gif", "wo3.wav"));
		myCharacters.add(new Character("you", "ni3", "ni3.gif", "ni3.wav"));
		myCharacters.add(new Character("he", "ta1", "ta1he.gif", "ta1.wav"));
		myCharacters.add(new Character("she", "ta1", "ta1she.gif", "ta1.wav"));
		myCharacters.add(new Character("it", "ta1", "ta1it.gif", "ta1.wav"));
		myRandom = new Random();
		reset();
	}

	public CharacterDrill2(String path, String filename) throws Exception {
		myCharacters = loadCharacters(path, filename);
		myRandom = new Random();
		reset();
	}

	public CharacterDrill2(String path, String filename, int answerIndex) throws Exception {
		myCharacters = loadCharacters(path, filename);
		myRandom = new Random();
		myAnswerIndex = answerIndex;
		myHintCount = 0;
	}

	
	
	
	public void reset() {
		myAnswerIndex = myRandom.nextInt(myCharacters.size());
		myHintCount = 0;
	}

	private List<Character> loadCharacters(String path, String filename) throws Exception {
		Scanner fileIn = new Scanner(new File(path, filename));
		List<Character> result = new ArrayList<Character>();
		Character character;
		String sentence;
		while (fileIn.hasNextLine()) {
			result.add(new Character(fileIn.nextLine()));
		}
		fileIn.close();
		return result;
	}

	public boolean guess(String guess) {
		return myCharacters.get(myAnswerIndex).getEnglishTranslation().equalsIgnoreCase(guess);
	}

	public String getAnswer() {
		return myCharacters.get(myAnswerIndex).getEnglishTranslation();
	}

	public String getHintText() {
		myHintCount++;
		switch (myHintCount) {
		case 1:
			return "Translate the character shown above.";
		case 2:
			return "PinYin: " + myCharacters.get(myAnswerIndex).getPinyin();
		case 3:
			return "Example: " + myCharacters.get(myAnswerIndex).getSentence();
		default:
			return "No more hints...";
		}
	}

	public String getHintImageFilename() {
		return myCharacters.get(myAnswerIndex).getImageFilename();
	}

	public String getHintPronunciationFilename() {
		return myCharacters.get(myAnswerIndex).getPronunciationFilename();
	}

}