package c13oop.text.simpledraw.simpledraw2;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JToggleButton;

/**
 * SimpledrawController implements a simple figure-drawing application that
 * allows the user to place and size figures on a 2D canvas.
 * 
 * @author kvlinden
 * @version Fall, 2009
 * @version Upgraded to inner classes, Spring, 2012
 */
public class SimpledrawController extends JFrame {

	private final static String PATH = "src/c13oop/text/simpledraw/simpledraw2/data/";
	private static final Dimension DEFAULT_BUTTON_DIMENSION = new Dimension(50, 50);

	private JPanel buttonPanel, figureButtonPanel, colorButtonPanel, fillButtonPanel;
	private JButton refreshButton;

	private JToggleButton rectangleButton, ellipseButton, lineButton, doodleButton, blackButton,
			blueButton, redButton, greenButton, filledButton, emptyButton;
	private ButtonGroup figureButtonGroup, colorButtonGroup, fillButtonGroup;

	private SimpledrawPanel drawingPanel;

	public SimpledrawController() throws Exception {
		setTitle("Simpledraw");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		figureButtonGroup = new ButtonGroup();
		figureButtonPanel = new JPanel();
		figureButtonPanel.setBorder(BorderFactory.createLineBorder(Color.black));

		// testing
		colorButtonGroup = new ButtonGroup();
		colorButtonPanel = new JPanel();
		colorButtonPanel.setBorder(BorderFactory.createLineBorder(Color.black));

		fillButtonGroup = new ButtonGroup();
		fillButtonPanel = new JPanel();
		fillButtonPanel.setBorder(BorderFactory.createLineBorder(Color.black));

		refreshButton = new JButton("Refresh");
		refreshButton.setPreferredSize(new Dimension(100, 50));
		refreshButton.addActionListener(new RefreshButtonListener());

		buttonPanel = new JPanel();
		buttonPanel.add(figureButtonPanel);
		buttonPanel.add(colorButtonPanel);
		buttonPanel.add(fillButtonPanel);
		buttonPanel.add(refreshButton);

		rectangleButton = makeButton("Rectangle", figureButtonGroup, figureButtonPanel,
				new RectangleButtonListener());
		rectangleButton.setSelected(true);
		ellipseButton = makeButton("Ellipse", figureButtonGroup, figureButtonPanel,
				new EllipseButtonListener());
		lineButton = makeButton("Line", figureButtonGroup, figureButtonPanel,
				new LineButtonListener());
		doodleButton = makeButton("Doodle", figureButtonGroup, figureButtonPanel,
				new DoodleButtonListener());

		blackButton = makeButton("Black", colorButtonGroup, colorButtonPanel,
				new BlackButtonListener());
		blackButton.setSelected(true);
		redButton = makeButton("Red", colorButtonGroup, colorButtonPanel, new RedButtonListener());
		blueButton = makeButton("Blue", colorButtonGroup, colorButtonPanel,
				new BlueButtonListener());
		greenButton = makeButton("Green", colorButtonGroup, colorButtonPanel,
				new GreenButtonListener());

		emptyButton = makeButton("Empty", fillButtonGroup, fillButtonPanel,
				new EmptyButtonListener());
		emptyButton.setSelected(true);
		filledButton = makeButton("Filled", fillButtonGroup, fillButtonPanel,
				new FilledButtonListener());

		drawingPanel = new SimpledrawPanel(Figure.Type.RECTANGLE, Color.BLACK, false);
		drawingPanel.init();

		add(buttonPanel, BorderLayout.NORTH);
		add(drawingPanel, BorderLayout.CENTER);
	}

	/**
	 * This method constructs a new button.
	 * 
	 * @param buttonType
	 *            the type of the button (e.g., "Rectangle", "Ellipse") - This
	 *            is used to get the button's icon.
	 * @param group
	 *            the button group in which the button should be placed
	 * @param panel
	 *            the panel in which the button should be placed
	 * @param listener
	 *            the action listener for the button
	 * @return the new button object
	 */
	private JToggleButton makeButton(String buttonType, ButtonGroup group, JPanel panel,
			ActionListener listener) {
		JToggleButton result = new JToggleButton(new ImageIcon(PATH + buttonType + ".jpg"));
		result.addActionListener(listener);
		result.setActionCommand(buttonType);
		result.setPreferredSize(DEFAULT_BUTTON_DIMENSION);
		result.setBackground(Color.white);
		group.add(result);
		panel.add(result);
		return result;
	}

	class RefreshButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.refresh();
		}
	}

	class RectangleButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFigureMode("rectangle");
		}
	}

	class EllipseButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFigureMode("ellipse");
		}
	}

	class LineButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFigureMode("line");
		}
	}

	class DoodleButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFigureMode("doodle");
		}
	}

	class BlackButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setColorMode(Color.BLACK);
		}
	}

	class RedButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setColorMode(Color.RED);
		}
	}

	class GreenButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setColorMode(Color.GREEN);
		}
	}

	class BlueButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setColorMode(Color.BLUE);
		}
	}

	class FilledButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFilledMode(true);
		}
	}

	class EmptyButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			drawingPanel.setFilledMode(false);
		}
	}

	public static void main(String args[]) throws Exception {
		SimpledrawController controller = new SimpledrawController();
		controller.pack();
		controller.setVisible(true);
	}
}