package c13oop.text.simpledraw.simpledraw2;

import java.awt.Color;
import java.awt.Point;
import java.util.ArrayList;

import processing.core.PApplet;
import c13oop.text.simpledraw.simpledraw2.Figure.Type;

/**
 * SimpledrawPanel implements a PApplet-based drawing canvas for the Simpledraw
 * application.
 * 
 * @author kvlinden
 * @version Fall, 2009
 */
public class SimpledrawPanel extends PApplet {

	private final int BACKGROUND_COLOR = color(255);

	private ArrayList<Figure> myFigures;
	// private Figure.Type myFigureMode;
	private String myFigureMode;
	private int myColorMode;
	private boolean myFilledMode;
	private Figure myCurrentFigure;

	public SimpledrawPanel(Figure.Type figureMode, Color colorMode, boolean filledMode)
			throws Exception {
		myFigures = new ArrayList<Figure>();
		// myFigureMode = Figure.Type.RECTANGLE;
		myFigureMode = "rectangle";
		setColorMode(colorMode);
		myFilledMode = filledMode;
	}

	// public void setFigureMode(Figure.Type mode) {
	// myFigureMode = mode;
	// }

	public void setFigureMode(String mode) {
		myFigureMode = mode;
	}

	// Processing colors are integers. This should use a switch statement.
	public void setColorMode(Color color) {
		if (color == Color.RED) {
			myColorMode = color(255, 0, 0);
		} else if (color == Color.GREEN) {
			myColorMode = color(0, 255, 0);
		} else if (color == Color.BLUE) {
			myColorMode = color(0, 0, 255);
		} else {
			myColorMode = color(0);
		}
	}

	public void setFilledMode(boolean mode) {
		myFilledMode = mode;
	}

	public void refresh() {
		for (int i = 0; i < myFigures.size(); i++) {
			myFigures.get(i).render(this);
		}
	}

	public void setup() {
		size(600, 400);
		background(BACKGROUND_COLOR);
	}

	public void draw() {
		// draw() must run to handle Processing mouse interaction.
	}

	/**
	 * Create a new figure object of the appropriate type and initialize its
	 * start point, color and filled status.
	 */
	public void mousePressed() {
		if (myFigureMode.equals("rectangle")) {
			myCurrentFigure = new Rectangle(new Point(mouseX, mouseY), myColorMode, myFilledMode);
		} else if (myFigureMode.equals("ellipse")) {
			myCurrentFigure = new Ellipse(new Point(mouseX, mouseY), myColorMode, myFilledMode);
		} else if (myFigureMode.equals("doodle")) {
			myCurrentFigure = new Doodle(new Point(mouseX, mouseY), myColorMode);
		} else {
			myCurrentFigure = new Line(new Point(mouseX, mouseY), myColorMode);
		}
	}

	/**
	 * Erase the previous temporary figure, change the end point to the current
	 * mouse position and redraw the temporary figure.
	 */
	public void mouseDragged() {
		int figureColor = myCurrentFigure.getColor();
		myCurrentFigure.setColor(BACKGROUND_COLOR);
		myCurrentFigure.render(this);
		myCurrentFigure.setColor(figureColor);
		myCurrentFigure.updatePoint(new Point(mouseX, mouseY));
		myCurrentFigure.render(this);
	}

	/**
	 * Add the new figure just created to the myFigures list. 
	 */
	public void mouseReleased() {
		myFigures.add(myCurrentFigure);
	}

	// @Override
	// public void paint(Graphics g) {
	// System.out.println("repaint");
	// for (int i = 0; i < myFigures.size(); i++) {
	// myFigures.get(i).render(this);
	// }
	// }

}
